@@ -4,11 +4,11 @@ use 5.006;
 use strict;
 use warnings;
 
-$Object::Declare::VERSION = '0.21';
+our $VERSION = '0.24';
 
 sub import {
     my $class       = shift;
-    my %args        = ((@_ and ref($_[0])) ? (mapping => $_[0]) : @_) or return; 
+    my %args        = ((@_ and ref($_[0])) ? (mapping => $_[0]) : @_) or return;
     my $from        = caller;
 
     my $mapping     = $args{mapping} or return;
@@ -111,7 +111,10 @@ sub _declare {
         $replace->( "UNIVERSAL::$sym" => sub {
             # Turn "is some_field" into "some_field is 1"
             my ($key, @vals) = ref($prefix) ? $prefix->(@_) : ($prefix.$_[0] => 1) or return;
-
+            # If the copula returns a ready-to-use katamari object,
+            # don't try to roll it by ourself.
+            return $key
+                if ref($key) && ref($key) eq 'Object::Declare::Katamari';
             $key = $aliases->{$key} if $aliases and exists $aliases->{$key};
             unshift @vals, $key;
             bless( \@vals => 'Object::Declare::Katamari' );
@@ -134,7 +137,7 @@ sub _declare {
     }
 
     my @overridden = map { "$from\::$_" } keys %$mapping;
-    # Now install the collector symbols from class mappings 
+    # Now install the collector symbols from class mappings
     my $toggle_subs = sub {
         foreach my $sym (@overridden) {
             no strict 'refs';
@@ -195,7 +198,7 @@ sub _make_object {
 
 package Object::Declare::Katamari;
 
-use overload "!" => \&negation;
+use overload "!" => \&negation, fallback => 1;
 
 sub negation {
     my @katamari = @{$_[0]} or return ();
@@ -210,7 +213,7 @@ sub unroll {
     my @unrolled;
 
     unshift @unrolled, pop(@katamari)->unroll
-        while ref($katamari[-1]) eq __PACKAGE__; 
+        while ref($katamari[-1]) eq __PACKAGE__;
 
     if (@katamari == 1) {
         # single value: "is foo"
@@ -232,10 +235,16 @@ sub unroll {
 
 __END__
 
+=pod
+
 =head1 NAME
 
 Object::Declare - Declarative object constructor
 
+=head1 VERSION
+
+version 0.24
+
 =head1 SYNOPSIS
 
     use Object::Declare ['MyApp::Column', 'MyApp::Param'];
@@ -298,9 +307,13 @@ After the declarator block finishes execution, all helper functions are
 removed from the package.  Same-named functions (such as C<&is> and C<&are>)
 that existed before the declarator's execution are restored correctly.
 
+=head1 VERSION
+
+version 0.24
+
 =head1 NOTES
 
-If you export the declarator to another package via C<@EXPORT>, be sure 
+If you export the declarator to another package via C<@EXPORT>, be sure
 to export all mapping keys as well.  For example, this will work for the
 example above:
 
@@ -342,4 +355,132 @@ LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 DEALINGS IN THE SOFTWARE.
 
+=head1 AUTHOR
+
+Shlomi Fish <shlomif@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2006 by Audrey Tang.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+L<https://github.com/shlomif/perl-Object-Declare/issues>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+
+=head1 SUPPORT
+
+=head2 Perldoc
+
+You can find documentation for this module with the perldoc command.
+
+  perldoc Object::Declare
+
+=head2 Websites
+
+The following websites have more information about this module, and may be of help to you. As always,
+in addition to those websites please use your favorite search engine to discover more resources.
+
+=over 4
+
+=item *
+
+MetaCPAN
+
+A modern, open-source CPAN search engine, useful to view POD in HTML format.
+
+L<https://metacpan.org/release/Object-Declare>
+
+=item *
+
+Search CPAN
+
+The default CPAN search engine, useful to view POD in HTML format.
+
+L<http://search.cpan.org/dist/Object-Declare>
+
+=item *
+
+RT: CPAN's Bug Tracker
+
+The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
+
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=Object-Declare>
+
+=item *
+
+AnnoCPAN
+
+The AnnoCPAN is a website that allows community annotations of Perl module documentation.
+
+L<http://annocpan.org/dist/Object-Declare>
+
+=item *
+
+CPAN Ratings
+
+The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
+
+L<http://cpanratings.perl.org/d/Object-Declare>
+
+=item *
+
+CPANTS
+
+The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
+
+L<http://cpants.cpanauthors.org/dist/Object-Declare>
+
+=item *
+
+CPAN Testers
+
+The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.
+
+L<http://www.cpantesters.org/distro/O/Object-Declare>
+
+=item *
+
+CPAN Testers Matrix
+
+The CPAN Testers Matrix is a website that provides a visual overview of the test results for a distribution on various Perls/platforms.
+
+L<http://matrix.cpantesters.org/?dist=Object-Declare>
+
+=item *
+
+CPAN Testers Dependencies
+
+The CPAN Testers Dependencies is a website that shows a chart of the test results of all dependencies for a distribution.
+
+L<http://deps.cpantesters.org/?module=Object::Declare>
+
+=back
+
+=head2 Bugs / Feature Requests
+
+Please report any bugs or feature requests by email to C<bug-object-declare at rt.cpan.org>, or through
+the web interface at L<https://rt.cpan.org/Public/Bug/Report.html?Queue=Object-Declare>. You will be automatically notified of any
+progress on the request by the system.
+
+=head2 Source Code
+
+The code is open to the world, and available for you to hack on. Please feel free to browse it and play
+with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
+from your repository :)
+
+L<https://github.com/shlomif/perl-Object-Declare>
+
+  git clone git://github.com/shlomif/perl-Object-Declare.git
+
 =cut
